@@ -4,8 +4,7 @@ from pathlib import Path
 
 from dotenv import load_dotenv
 
-from django_configuration_management.secrets import (decrypt_value,
-                                                     encrypt_value)
+from django_configuration_management.secrets import decrypt_value, encrypt_value
 from django_configuration_management.yml_utils import validate_key_name
 
 
@@ -15,10 +14,9 @@ def load_env(environment: str):
         load_dotenv(dotenv_path=env_path, verbose=True)
         return
 
-    print(
+    raise AssertionError(
         f"env not found: {env_path}. This file is required and must contain your ENC_KEY"
     )
-    exit(1)
 
 
 def gather_user_input():
